A function to initalize the directory for ebod. This is the function that is called when the ebod init command is executed. It creates the ./.ebod/metadata.json file. Scans the directory for information of files and loads the metadata into metadata.json.
Function with which all the progress is logged in ebod. The LogType has three options: Info, Ok and Err. Info is mapped to yellow, Ok to green and Err to red for efficient and easy to read logging.
The function that is called when ebod sync command is invoked. It syncs the files in the source and the destination directory. It works by first backing up the src into dest. Then dest is initialized again and then this dist is backed up into the src directory.
Then the copies in the src directory are cleared to avoid duplication.